Module blaxel.llamaindex.tools
==============================

Functions
---------

`bl_tools(tools_names: list[str], **kwargs) ‑> list[llama_index.core.tools.function_tool.FunctionTool]`
:   

`get_llamaindex_tool(tool: blaxel.core.tools.types.Tool) ‑> llama_index.core.tools.function_tool.FunctionTool`
: